package com.test;

import static org.junit.Assert.assertTrue;

import java.util.Date;

import org.junit.After;
import org.junit.Before;
import org.junit.Test;

import com.google.appengine.tools.development.testing.LocalDatastoreServiceTestConfig;
import com.google.appengine.tools.development.testing.LocalServiceTestHelper;
import com.test.model.Band;
import com.test.model.Concert;
import com.test.model.CurrencyAmount;
import com.test.model.CurrencyAmount.CurrencyType;
import com.test.model.dao.ConcertDao;

public class MyTest {

    private final LocalServiceTestHelper helper = new LocalServiceTestHelper(
            new LocalDatastoreServiceTestConfig());

    // private ObjectDatastore datastore;

    @Before
    public void setupDatastore() {
        helper.setUp();
    }

    @After
    public void tearDownDatastore() {
        helper.tearDown();
    }

    @Test
    public void testUpdate() {
        // Create concert
        ConcertDao concertDao = new ConcertDao();
        Concert concert = new Concert(new Date(), new CurrencyAmount(
                CurrencyType.USD, 25.0));
        concertDao.create(concert);
        Long concertId = concert.getId();
        // Add band
        concert = concertDao.findConcertById(concertId);
        Band band = new Band("Radiohead", new CurrencyAmount(CurrencyType.GBP,
                15980.0));
        concert.getBands().add(band);
        concertDao.associate(concert);
        concertDao.update(concert);
        // Modify existing band
        concert = concertDao.findConcertById(concertId);
        band = concert.getBands().get(0);
        band.setName("Coldplay");
        concertDao.update(concert);
        // I don't expect the band to be updated in the datastore because I
        // modified
        // the band but updated the concert. No dirty detection.
        concert = concertDao.findConcertById(concertId);
        assertTrue(concert.getBands().get(0).getName().equals("Radiohead"));
        band = concert.getBands().get(0);
        band.setName("Coldplay");
        concertDao.updateChild(concert.getBands());
        // Band should be coldplay
        concert = concertDao.findConcertById(concertId);
        assertTrue(concert.getBands().get(0).getName().equals("Coldplay"));
    }

}
